import { IMethodDecorator, MetadataExtends, MetadataAdapter } from 'tsioc';
import { RequestMethod } from '../RequestMethod';
import { RouteMetadata } from './metadata';
/**
 * route decorator type define.
 *
 * @export
 * @interface IRouteDecorator
 * @template T
 */
export interface IRouteDecorator<T extends RouteMetadata> extends IMethodDecorator<T> {
    (route: string, contentType?: string): MethodDecorator;
}
/**
 * custom define Request method. route decorator type define.
 *
 * @export
 * @interface IRouteMethodDecorator
 * @template T
 */
export interface IRouteMethodDecorator<T extends RouteMetadata> extends IMethodDecorator<T> {
    (route: string, contentType?: string, method?: RequestMethod): MethodDecorator;
}
/**
 * create route decorator.
 *
 * @export
 * @template T
 * @param {RequestMethod} [method]
 * @param { MetadataExtends<T>} [metaExtends]
 */
export declare function createRouteDecorator<T extends RouteMetadata>(method?: RequestMethod, adapter?: MetadataAdapter, metaExtends?: MetadataExtends<T>): IRouteDecorator<T>;
export declare const Route: IRouteMethodDecorator<RouteMetadata>;
