"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tsioc_1 = require("tsioc");
const RequestMethod_1 = require("../RequestMethod");
const util_1 = require("util");
/**
 * create route decorator.
 *
 * @export
 * @template T
 * @param {RequestMethod} [method]
 * @param { MetadataExtends<T>} [metaExtends]
 */
function createRouteDecorator(method, adapter, metaExtends) {
    return tsioc_1.createMethodDecorator('Route', args => {
        if (adapter) {
            adapter(args);
        }
        args.next({
            isMetadata: (arg) => tsioc_1.isClassMetadata(arg, ['route', 'method']),
            match: (arg) => util_1.isString(arg),
            setMetadata: (metadata, arg) => {
                metadata.route = arg;
            }
        });
        args.next({
            match: (arg) => util_1.isString(arg),
            setMetadata: (metadata, arg) => {
                metadata.contentType = arg;
            }
        });
        args.next({
            match: (arg) => util_1.isNumber(arg),
            setMetadata: (metadata, arg) => {
                metadata.method = arg;
            }
        });
    }, metadata => {
        if (metaExtends) {
            metadata = metaExtends(metadata);
        }
        metadata.method = method || RequestMethod_1.RequestMethod.Get;
        return metadata;
    });
}
exports.createRouteDecorator = createRouteDecorator;
exports.Route = createRouteDecorator();

//# sourceMappingURL=../sourcemaps/decorators/Route.js.map
