"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ResultValue_1 = require("./ResultValue");
const stream_1 = require("stream");
const util_1 = require("../util");
const Configuration_1 = require("../Configuration");
const fs_1 = require("fs");
const path_1 = require("path");
const errors_1 = require("../errors");
/**
 * controller method return result type of file.
 *
 * @export
 * @class FileResult
 */
class FileResult extends ResultValue_1.ResultValue {
    constructor(file, contentType, fileDownloadName) {
        super(contentType);
        this.file = file;
        this.fileDownloadName = fileDownloadName;
    }
    async sendValue(ctx, container) {
        let defer = util_1.Defer.create();
        let file = this.file;
        let contentType = this.contentType;
        let confige = container.get(Configuration_1.Configuration);
        if (file instanceof String) {
            let filepath = path_1.join(confige.rootdir, file);
            if (fs_1.existsSync(filepath)) {
                fs_1.readFile(filepath, contentType || 'utf8', (err, data) => {
                    if (err) {
                        defer.reject(err);
                    }
                    else {
                        defer.resolve(new Buffer(data));
                    }
                });
            }
        }
        else if (file instanceof Buffer) {
            defer.resolve(file);
        }
        else if (file instanceof stream_1.Stream) {
            file.once('end', (data) => {
                defer.resolve(new Buffer(data));
            })
                .once('error', defer.reject);
        }
        return defer.promise
            .then(buffer => {
            if (this.fileDownloadName) {
                ctx.attachment(this.fileDownloadName);
            }
            ctx.body = buffer;
        }, err => {
            throw new errors_1.BadRequestError(err.toString());
        });
    }
}
exports.FileResult = FileResult;

//# sourceMappingURL=../sourcemaps/restults/FileResult.js.map
