"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tsioc_1 = require("tsioc");
const NotFoundRoute_1 = require("./NotFoundRoute");
const util_1 = require("util");
/**
 * base route.
 *
 * @export
 * @class BaseRoute
 * @extends {Composite}
 * @implements {IRoute}
 */
class BaseRoute extends tsioc_1.Composite {
    constructor(route) {
        super(route);
        this.url = route.substring(0);
    }
    add(node) {
        let baseUrl = this.cutEmptyPath(this.url, true);
        node.url = baseUrl + node.url;
        super.add(node);
        return this;
    }
    cutEmptyPath(routPath, foreNull = false) {
        if (foreNull && routPath === '/') {
            return '';
        }
        if (/\/\s*$/.test(routPath)) {
            routPath = routPath.substring(0, routPath.lastIndexOf('/'));
        }
        if (/\?\S*$/.test(routPath)) {
            routPath = routPath.substring(0, routPath.lastIndexOf('?'));
        }
        return routPath;
    }
    match(ctx) {
        let prefix = util_1.isString(ctx) ? ctx : ctx.url;
        let route = this.find((r) => {
            return r.url && prefix && prefix.indexOf(r.url) === 0;
        }, tsioc_1.Mode.traverseLast);
        return route;
    }
    empty() {
        return NotFoundRoute_1.notFoundRoute;
    }
}
exports.BaseRoute = BaseRoute;

//# sourceMappingURL=../sourcemaps/router/BaseRoute.js.map
